@@ -45,10 +45,10 @@ def find_rare_class(classes, verbose=0):
     else:
         return int(pd.Series(counts).idxmin())
 ################################################################################
-def QuickML_Stacking(X_train, y_train, X_test='', modeltype='Regression',Boosting_Flag=False, 
+def QuickML_Stacking(X_train, y_train, X_test='', modeltype='Regression',Boosting_Flag=False,
                     scoring='', verbose=0):
     """
-    Quickly build Stacks of multiple model results 
+    Quickly build Stacks of multiple model results
     Input must be a clean data set (only numeric variables, no categorical or string variables).
     """
     X_train = copy.deepcopy(X_train)
@@ -78,10 +78,11 @@ def QuickML_Stacking(X_train, y_train, X_test='', modeltype='Regression',Boostin
             scv = KFold(n_splits=FOLDS, random_state=seed, shuffle=True)
             if Boosting_Flag:
                 ######    Bagging models if Bagging is chosen ####
-                model4 = BaggingRegressor(DecisionTreeRegressor(random_state=seed),
-                                            n_estimators=NUMS,random_state=seed)
+                #model4 = BaggingRegressor(DecisionTreeRegressor(random_state=seed),
+                #                            n_estimators=NUMS,random_state=seed)
+                model4 = LinearSVR()
                 results = cross_val_predict(model4,X_train,y_train, cv=scv,n_jobs=-1)
-                estimators.append(('Bagging1',model4))
+                estimators.append(('Linear_SVR',model4))
                 estimator_length.append(1)
             elif Boosting_Flag is None:
                 ####   Tree models if Linear chosen #####
@@ -147,10 +148,11 @@ def QuickML_Stacking(X_train, y_train, X_test='', modeltype='Regression',Boostin
             scv = KFold(n_splits=FOLDS, random_state=seed, shuffle=True)
             if Boosting_Flag:
                 ######    Bagging models if Bagging is chosen ####
-                model4 = BaggingRegressor(DecisionTreeRegressor(random_state=seed),
-                                            n_estimators=NUMS,random_state=seed)
+                #model4 = BaggingRegressor(DecisionTreeRegressor(random_state=seed),
+                #                            n_estimators=NUMS,random_state=seed)
+                model4 = LinearSVR()
                 results = model4.fit(X_train,y_train).predict(X_test)
-                estimators.append(('Bagging1',model4))
+                estimators.append(('Linear_SVR',model4))
                 estimator_length.append(1)
             elif Boosting_Flag is None:
                 ####   Tree models if Linear chosen #####
@@ -216,4 +218,4 @@ def QuickML_Stacking(X_train, y_train, X_test='', modeltype='Regression',Boostin
     if verbose == 1:
         print('    Time taken for Stacking: %0.1f seconds' %(time.time()-start_time))
     return ls, results
-#########################################################
\ No newline at end of file
+#########################################################
